//
// This program demonstrates how to use LeakChecker to do function level leak detection.
//
// To find the leak, press "F5" to start debugging.
// Memory leak will be dumped to the "Output" pane.
//

#include "stdafx.h"
#include <Windows.h>
#include <atlbase.h>
#include <atlstr.h>

#ifdef _DEBUG
#include "LeakChecker.h"
#pragma comment(lib, "LeakChecker")
#endif

void SuspectLeakFunction()
{
	void *p;

	for (int i = 0; i < 2000; i++)
	{
		p = malloc(100);
	}
}

void SuspectLeakFunction2(CSimpleArray<CString> &MyArray)
{
	MyArray.Add("string");
	// The CString object added to the array will be automatically
	// destructed when array is destructed.
	// So there will be no memory leak.
	// But if this function was called many times,
	// it will result memory exhausted.
}

void SuspectLeakFunction3()
{
	char *p = new char[100];
	delete p;
}

int _tmain(int argc, _TCHAR* argv[])
{
	//////////////////////////////////////////////////////////////////////////
	OutputDebugString(_T("Demo: Check leak status of SuspectLeakFunction\n"));
#ifdef _DEBUG
	LeakCheckerSetOptions(16, FALSE, TRUE);
	LeakCheckerStart();
#endif

	SuspectLeakFunction();
	OutputDebugString(_T("Demo: SuspectLeakFunction End\n"));

#ifdef _DEBUG
	LeakCheckerStop();
	LeakCheckerDump();
#endif
	//////////////////////////////////////////////////////////////////////////


	//////////////////////////////////////////////////////////////////////////
	OutputDebugString(_T("Demo: Check leak status of SuspectLeakFunction2\n"));
#ifdef _DEBUG
	LeakCheckerStart();
#endif

	{
		CSimpleArray<CString> leak_array;
		SuspectLeakFunction2(leak_array);
		// leak_array will be destructed here, so you won't see any leak.
	}
	OutputDebugString(_T("Demo: SuspectLeakFunction2 End\n"));

#ifdef _DEBUG
	LeakCheckerStop();
	LeakCheckerDump();
#endif
	//////////////////////////////////////////////////////////////////////////


	//////////////////////////////////////////////////////////////////////////
	OutputDebugString(_T("Demo: Check leak status of SuspectLeakFunction2\n"));
#ifdef _DEBUG
	LeakCheckerStart();
#endif

	// leak_array2 will be destructed at main function exit
	CSimpleArray<CString> leak_array2;
	SuspectLeakFunction2(leak_array2);
	OutputDebugString(_T("Demo: SuspectLeakFunction2 End\n"));

#ifdef _DEBUG
	LeakCheckerStop();
	LeakCheckerDump();
#endif
	//////////////////////////////////////////////////////////////////////////


	//////////////////////////////////////////////////////////////////////////
	OutputDebugString(_T("Demo: Check leak status of SuspectLeakFunction3\n"));
#ifdef _DEBUG
	LeakCheckerStart();
#endif

	SuspectLeakFunction3();
	OutputDebugString(_T("Demo: SuspectLeakFunction3 End\n"));

#ifdef _DEBUG
	LeakCheckerStop();
	LeakCheckerDump();
#endif

	return 0;
}

