
// Setup program for LeakChecker for Visual Studio 2008
//
// LeakChecker will be installed to:
//   VC\include\LeakChecker.h
//   VC\lib\LeakChecker.lib (32bit)
//   VC\lib\amd64\LeakChecker.lib (64bit)
//   WINDOWS\system32\LeakChecker.dll (64bit)
//   WINDOWS\SysWOW64\LeakChecker.dll (32bit)

main();

function main()
{
	// Decode command line arguments
	var bDebug = false;
	var bElevated = false;
	var bWow64 = false;
	var Args = WScript.Arguments;
	for (var i = 0; i < Args.length; i++)
	{
		if (Args(i) == "/debug")
			bDebug = true;
		else if (Args(i) == "/elevated")
			bElevated = true;
	}

	// See if UAC is enabled
	var Shell = WScript.CreateObject("Shell.Application");
	if (!bElevated && Shell.IsRestricted("System", "EnableLUA"))
	{
		// Check that the script is being run interactively.
		if (!WScript.Interactive)
		{
			WScript.Echo("ERROR: Elevation required.");
			return;
		}
		
		// Now relaunch the script, using the "RunAs" verb to elevate
		var strParams = "\"" + WScript.ScriptFullName + "\"";
		if (bDebug)
			strParams += " /debug";
		strParams += " /elevated";
		Shell.ShellExecute(WScript.FullName, strParams, null, "RunAs");
		return;
	}
	
	// Create shell object
	var WSShell = WScript.CreateObject("WScript.Shell");
	// Create file system object
	var FileSys = WScript.CreateObject("Scripting.FileSystemObject");

	var strValue;

	try
	{
		var strVCKey = "HKLM\\Software\\Microsoft\\VisualStudio\\9.0\\Setup\\VC\\ProductDir";
		strValue = WSShell.RegRead(strVCKey);
	}
	catch(e)
	{
		try
		{
			var strVCKey_x64 = "HKLM\\Software\\Wow6432Node\\Microsoft\\VisualStudio\\9.0\\Setup\\VC\\ProductDir";
			strValue = WSShell.RegRead(strVCKey_x64);
			bWow64 = true;
		}
		catch(e)
		{
			WScript.Echo("ERROR: Cannot find where Visual Studio 2008 is installed.");
			return;
		}
	}

	// VC\include\LeakChecker.h
	var strDestFolder = FileSys.BuildPath(strValue, "include");
	if (bDebug)
		WScript.Echo("Destination: " + strDestFolder);
	if (!FileSys.FolderExists(strDestFolder))
	{
		WScript.Echo("ERROR: Cannot find destination folder (should be: " + strDestFolder + ")");
		return;
	}

	try
	{
		var strDest = FileSys.BuildPath(strDestFolder, "LeakChecker.h");
		FileSys.DeleteFile(strDest);
	}
	catch (e)
	{
		var strError = "no info";
		if (e.description.length != 0)
			strError = e.description;
		WScript.Echo("ERROR: Cannot delete file (" + strError + ")");
	}

	// VC\lib\LeakChecker.lib (32bit)
	strDestFolder = FileSys.BuildPath(strValue, "lib");
	if (bDebug)
		WScript.Echo("Destination: " + strDestFolder);
	if (!FileSys.FolderExists(strDestFolder))
	{
		WScript.Echo("ERROR: Cannot find destination folder (should be: " + strDestFolder + ")");
		return;
	}

	try
	{
		var strDest = FileSys.BuildPath(strDestFolder, "LeakChecker.lib");
		FileSys.DeleteFile(strDest);
	}
	catch (e)
	{
		var strError = "no info";
		if (e.description.length != 0)
			strError = e.description;
		WScript.Echo("ERROR: Cannot delete file (" + strError + ")");
	}

	// VC\lib\amd64\LeakChecker.lib (64bit)
	strDestFolder = FileSys.BuildPath(strValue, "lib\\amd64");
	if (bDebug)
		WScript.Echo("Destination: " + strDestFolder);
	if (FileSys.FolderExists(strDestFolder))
	{
		// Copy files
		try
		{
			var strDest = FileSys.BuildPath(strDestFolder, "LeakChecker.lib");
			if (FileSys.FileExists(strDest))
				FileSys.DeleteFile(strDest);
		}
		catch (e)
		{
			var strError = "no info";
			if (e.description.length != 0)
				strError = e.description;
			WScript.Echo("ERROR: Cannot delete file (" + strError + ")");
		}
	}
	
	// WINDOWS\system32\LeakChecker.dll
	strDestFolder = FileSys.GetSpecialFolder(1);
	if (bDebug)
		WScript.Echo("Destination: " + strDestFolder);
	if (!FileSys.FolderExists(strDestFolder))
	{
		WScript.Echo("ERROR: Cannot find destination folder (should be: " + strDestFolder + ")");
		return;
	}

	try
	{
		var strDest = FileSys.BuildPath(strDestFolder, "LeakChecker.dll");
		if (FileSys.FileExists(strDest))
			FileSys.DeleteFile(strDest);
	}
	catch(e)
	{
		var strError = "no info";
		if (e.description.length != 0)
			strError = e.description;
		WScript.Echo("ERROR: Cannot delete file (" + strError + ")");
	}

	if (bWow64)
	{
		// WINDOWS\SysWOW64\LeakChecker.dll (32bit)
		strDestFolder = FileSys.BuildPath(FileSys.GetSpecialFolder(0), "SysWOW64");
		if (bDebug)
			WScript.Echo("Destination: " + strDestFolder);
		if (!FileSys.FolderExists(strDestFolder))
		{
			WScript.Echo("ERROR: Cannot find destination folder (should be: " + strDestFolder + ")");
			return;
		}

		// Copy files
		try
		{
			var strDest = FileSys.BuildPath(strDestFolder, "LeakChecker.dll");
			FileSys.DeleteFile(strDest);
		}
		catch (e)
		{
			var strError = "no info";
			if (e.description.length != 0)
				strError = e.description;
			WScript.Echo("ERROR: Cannot delete file (" + strError + ")");
		}
	}
	
	WScript.Echo("LeakChecker successfully uninstalled!");
}
